@@ -37,21 +37,17 @@ class QCheckBox;
 class QRadioButton;
 class QPushButton;
 
-namespace Akonadi
-{
+namespace Akonadi {
 class IncidenceChanger;
 class ETMCalendar;
 }
 
-namespace CalendarSupport
-{
-
+namespace CalendarSupport {
 class CALENDARSUPPORT_EXPORT ArchiveDialog : public QDialog
 {
     Q_OBJECT
 public:
-    ArchiveDialog(const Akonadi::ETMCalendar::Ptr &calendar,
-                  Akonadi::IncidenceChanger *changer,
+    ArchiveDialog(const Akonadi::ETMCalendar::Ptr &calendar, Akonadi::IncidenceChanger *changer,
                   QWidget *parent = nullptr);
     ~ArchiveDialog();
 
@@ -60,28 +56,25 @@ Q_SIGNALS:
     void eventsDeleted();
     void autoArchivingSettingsModified();
 
-protected Q_SLOTS:
+private:
     void slotEventsDeleted();
     void slotUser1();
     void slotEnableUser1();
     void slotActionChanged();
-
-private:
     void showWhatsThis();
-    KUrlRequester *mArchiveFile;
-    KDateComboBox *mDateEdit;
-    QCheckBox *mDeleteCb;
-    QRadioButton *mArchiveOnceRB;
-    QRadioButton *mAutoArchiveRB;
-    QSpinBox *mExpiryTimeNumInput;
-    KComboBox *mExpiryUnitsComboBox;
-    QCheckBox *mEvents;
-    QCheckBox *mTodos;
-    Akonadi::IncidenceChanger *mChanger;
+    KUrlRequester *mArchiveFile = nullptr;
+    KDateComboBox *mDateEdit = nullptr;
+    QCheckBox *mDeleteCb = nullptr;
+    QRadioButton *mArchiveOnceRB = nullptr;
+    QRadioButton *mAutoArchiveRB = nullptr;
+    QSpinBox *mExpiryTimeNumInput = nullptr;
+    KComboBox *mExpiryUnitsComboBox = nullptr;
+    QCheckBox *mEvents = nullptr;
+    QCheckBox *mTodos = nullptr;
+    Akonadi::IncidenceChanger *mChanger = nullptr;
     Akonadi::ETMCalendar::Ptr mCalendar;
-    QPushButton *mUser1Button;
+    QPushButton *mUser1Button = nullptr;
 };
-
 }
 
 #endif
